@@ -1,11 +1,14 @@
 from typing import Optional, Dict, List, Tuple, Any
 import json
 import re
-from pathlib import Path
 import glob
+from pathlib import Path
 import logging
 
-from ecl2df import common
+import pandas as pd
+from fmu.ensemble import ScratchEnsemble
+
+from ecl2df import common, EclFiles
 
 
 def remove_invalid_colors(zonelist: List[Dict[str, Any]]) -> List[Dict[str, Any]]:
@@ -101,20 +104,61 @@ def read_stratigraphy(
     return None
 
 
+def get_ecl_datafile(ensemble_path: str) -> Optional[str]:
+    """Returns the first eclipse DATA file found in the ensemble_path.
+    If no DATA file is found it returns None.
+    """
+    for filename in glob.glob(f"{ensemble_path}/eclipse/model/*.DATA"):
+        return filename
+    return None
+
+
 def get_ecl_unit_system(ensemble_path: str) -> Optional[str]:
     """Returns the unit system of an eclipse deck. The options are \
     METRIC, FIELD, LAB and PVT-M.
 
-    If none of these are found, the function returns None, even though \
-    the default unit system is METRIC. This is because the unit system \
-    keyword could be in an include file.
-    """
-    for filename in glob.glob(f"{ensemble_path}/eclipse/model/*.DATA"):
-        with open(filename, "r") as handle:
-            ecl_data_lines = handle.readlines()
+    If none of these are found, the function returns METRIC
 
-        for unit_system in ["METRIC", "FIELD", "LAB", "PVT-M"]:
-            if any(line.startswith(unit_system) for line in ecl_data_lines):
-                return unit_system
+    If no eclipse DATA file is found in the ensemble path, it
+    returns None
+    """
+    datafile = get_ecl_datafile(ensemble_path)
+    if datafile is None:
         return None
-    return None
+    ecl_deck = EclFiles(datafile).get_ecldeck()
+    for keyword in ecl_deck:
+        if keyword.name in ["METRIC", "FIELD", "LAB", "PVT-M"]:
+            return keyword.name
+    return "METRIC"
+
+
+def read_well_connection_status(
+    ensemble_path: str, well_connection_status_file: str
+) -> Optional[pd.DataFrame]:
+    """Reads parquet file with well connection status data from the scratch disk.
+    Merges together files from all realizations, does some fixing of the column
+    data types, and returns it as a pandas dataframe.
+
+    fmu-ensemble is used to find the file names on the scratch disk
+
+    The well connection status data is extracted from the CPI data, which is 0 if the
+    connection is SHUT and >0 if the connection is OPEN. This is independent of
+    the status of the well.
+    """
+    ens = ScratchEnsemble("ens", ensemble_path)
+    df_files = ens.find_files(well_connection_status_file)
+
+    if df_files.empty:
+        return None
+
+    df = pd.DataFrame()
+    for _, row in df_files.iterrows():
+        df_real = pd.read_parquet(row.FULLPATH)
+        df_real["REAL"] = row.REAL
+        df = pd.concat([df, df_real])
+    df.I = pd.to_numeric(df.I)
+    df.J = pd.to_numeric(df.J)
+    df["K1"] = pd.to_numeric(df.K)
+    df = df.drop(["K"], axis=1)
+    df.DATE = pd.to_datetime(df.DATE).dt.date
+    return df
