@@ -73,13 +73,16 @@ class SurfaceLeafletModel:
     ) -> np.ndarray:
         surface = self.surface.copy()
         if clip_min or clip_max:
-            np.ma.clip(surface.values, clip_min, clip_max, out=surface.values)
+            np.ma.clip(surface.values, clip_min, clip_max, out=surface.values)  # type: ignore
         if unrotate:
             surface.unrotate()
         surface.fill(np.nan)
         values = surface.values
         if flip:
             values = np.flip(values.transpose(), axis=0)
+        # If all values are masked set to zero
+        if values.mask.all():
+            values = np.zeros(values.shape)
         return values
 
     @property
