@@ -22,6 +22,7 @@ pages:
 
 from ._bhp_qc import BhpQc
 from ._disk_usage import DiskUsage
+from ._line_plotter_fmu.line_plotter_fmu import LinePlotterFMU
 from ._history_match import HistoryMatch
 from ._horizon_uncertainty_viewer import HorizonUncertaintyViewer
 from ._inplace_volumes import InplaceVolumes
@@ -50,6 +51,8 @@ from ._surface_viewer_fmu import SurfaceViewerFMU
 from ._surface_with_grid_cross_section import SurfaceWithGridCrossSection
 from ._surface_with_seismic_cross_section import SurfaceWithSeismicCrossSection
 from ._structural_uncertainty import StructuralUncertainty
+from ._tornado_plotter_fmu import TornadoPlotterFMU
+from ._volumetric_analysis import VolumetricAnalysis
 from ._well_cross_section import WellCrossSection
 from ._well_cross_section_fmu import WellCrossSectionFMU
 from ._assisted_history_matching_analysis import AssistedHistoryMatchingAnalysis
