@@ -129,7 +129,7 @@ class LinePlotterFMU(WebvizPluginABC):
             Path(webviz_subsurface.__file__).parent
             / "_assets"
             / "js"
-            / "update_plotly_figure.js"
+            / "clientside_functions.js"
         )
 
         self._colors: Dict = unique_colors(self._ensemble_names, webviz_settings.theme)
@@ -161,9 +161,8 @@ class LinePlotterFMU(WebvizPluginABC):
                         initial_layout=self._initial_layout,
                     ),
                 ),
-                html.Div(
-                    className="framed",
-                    style={"flex": 1, "height": "89vh"},
+                wcc.Frame(
+                    style={"flex": 1, "height": "90vh"},
                     children=self._parameter_filter.layout,
                 ),
             ]
