@@ -20,7 +20,7 @@ from webviz_config.webviz_store import webvizstore
 
 from webviz_subsurface._models import EnsembleSetModel
 from webviz_subsurface._models import caching_ensemble_set_model_factory
-from .._private_plugins.tornado_plot import TornadoPlot
+from webviz_subsurface._components import TornadoWidget
 from .._datainput.fmu_input import (
     get_realizations,
     find_sens_type,
@@ -183,7 +183,8 @@ folder, to avoid risk of not extracting the right data.
             c
             for c in self.smry.columns
             if c not in ReservoirSimulationTimeSeriesOneByOne.ENSEMBLE_COLUMNS
-            and historical_vector(c, self.smry_meta, False) not in self.smry.columns
+            and historical_vector(c, self.smry_meta, False)
+            not in self.smry.columns  # PyCQA/pylint#4577 # pylint: disable=no-member
         ]
         self.initial_vector = (
             initial_vector
@@ -194,7 +195,7 @@ folder, to avoid risk of not extracting the right data.
         self.line_shape_fallback = set_simulation_line_shape_fallback(
             line_shape_fallback
         )
-        self.tornadoplot = TornadoPlot(
+        self.tornadoplot = TornadoWidget(
             app, webviz_settings, self.parameters, allow_click=True
         )
         self.uid = uuid4()
@@ -237,47 +238,29 @@ folder, to avoid risk of not extracting the right data.
     @property
     def ensemble_selector(self) -> html.Div:
         """Dropdown to select ensemble"""
-        return html.Div(
-            style={"paddingBottom": "30px"},
-            children=html.Label(
-                children=[
-                    html.Span("Ensemble:", style={"font-weight": "bold"}),
-                    dcc.Dropdown(
-                        id=self.ids("ensemble"),
-                        options=[{"label": i, "value": i} for i in self.ensembles],
-                        clearable=False,
-                        value=self.ensembles[0],
-                        persistence=True,
-                        persistence_type="session",
-                    ),
-                ]
-            ),
+        return wcc.Dropdown(
+            label="Ensemble",
+            id=self.ids("ensemble"),
+            options=[{"label": i, "value": i} for i in self.ensembles],
+            clearable=False,
+            value=self.ensembles[0],
         )
 
     @property
     def smry_selector(self) -> html.Div:
         """Dropdown to select ensemble"""
-        return html.Div(
-            style={"paddingBottom": "30px"},
-            children=html.Label(
-                children=[
-                    html.Span("Time series:", style={"font-weight": "bold"}),
-                    dcc.Dropdown(
-                        id=self.ids("vector"),
-                        options=[
-                            {
-                                "label": f"{simulation_vector_description(vec)} ({vec})",
-                                "value": vec,
-                            }
-                            for vec in self.smry_cols
-                        ],
-                        clearable=False,
-                        value=self.initial_vector,
-                        persistence=True,
-                        persistence_type="session",
-                    ),
-                ]
-            ),
+        return wcc.Dropdown(
+            label="Time series",
+            id=self.ids("vector"),
+            options=[
+                {
+                    "label": f"{simulation_vector_description(vec)} ({vec})",
+                    "value": vec,
+                }
+                for vec in self.smry_cols
+            ],
+            clearable=False,
+            value=self.initial_vector,
         )
 
     @property
@@ -313,64 +296,73 @@ folder, to avoid risk of not extracting the right data.
 
     @property
     def layout(self) -> html.Div:
-        return html.Div(
+        return wcc.FlexBox(
+            id=self.ids("layout"),
             children=[
-                wcc.FlexBox(
-                    id=self.ids("layout"),
-                    children=[
-                        html.Div(
-                            style={"flex": 2},
-                            children=[
-                                wcc.FlexBox(
-                                    children=[
-                                        self.ensemble_selector,
-                                        self.smry_selector,
-                                        dcc.Store(
-                                            id=self.ids("date-store"),
-                                            storage_type="session",
-                                        ),
-                                    ],
+                wcc.FlexColumn(
+                    flex=1,
+                    children=wcc.Frame(
+                        style={"height": "90vh"},
+                        children=[
+                            wcc.Selectors(
+                                label="Selectors",
+                                children=[self.ensemble_selector, self.smry_selector],
+                            ),
+                            dcc.Store(
+                                id=self.ids("date-store"),
+                                storage_type="session",
+                            ),
+                        ],
+                    ),
+                ),
+                wcc.FlexColumn(
+                    flex=3,
+                    children=wcc.Frame(
+                        style={"height": "90vh"},
+                        color="white",
+                        highlight=False,
+                        children=[
+                            html.Div(
+                                id=self.ids("graph-wrapper"),
+                                style={"height": "450px"},
+                                children=wcc.Graph(
+                                    id=self.ids("graph"),
+                                    clickData={"points": [{"x": self.initial_date}]},
                                 ),
-                                wcc.FlexBox(
-                                    children=[
-                                        html.Div(
-                                            id=self.ids("graph-wrapper"),
-                                            style={"height": "450px"},
-                                            children=wcc.Graph(
-                                                id=self.ids("graph"),
-                                                clickData={
-                                                    "points": [{"x": self.initial_date}]
-                                                },
-                                            ),
-                                        ),
-                                    ]
-                                ),
-                                html.Div(
-                                    children=[
-                                        html.Div(
-                                            id=self.ids("table_title"),
-                                            style={"textAlign": "center"},
-                                            children="",
-                                        ),
-                                        DataTable(
+                            ),
+                            html.Div(
+                                children=[
+                                    html.Div(
+                                        id=self.ids("table_title"),
+                                        style={"textAlign": "center"},
+                                        children="",
+                                    ),
+                                    html.Div(
+                                        style={"fontSize": "15px"},
+                                        children=DataTable(
                                             id=self.ids("table"),
                                             sort_action="native",
                                             filter_action="native",
                                             page_action="native",
                                             page_size=10,
                                         ),
-                                    ],
-                                ),
-                            ],
-                        ),
-                        html.Div(
-                            style={"flex": 1},
-                            id=self.ids("tornado-wrapper"),
-                            children=self.tornadoplot.layout,
-                        ),
-                    ],
+                                    ),
+                                ],
+                            ),
+                        ],
+                    ),
                 ),
-            ]
+                wcc.FlexColumn(
+                    flex=3,
+                    children=wcc.Frame(
+                        style={"height": "90vh"},
+                        color="white",
+                        highlight=False,
+                        id=self.ids("tornado-wrapper"),
+                        children=self.tornadoplot.layout,
+                    ),
+                ),
+            ],
         )
 
     # pylint: disable=too-many-statements
