@@ -16,14 +16,12 @@ import dash_core_components as dcc
 import webviz_core_components as wcc
 from dash.dependencies import Input, Output, State, ALL
 from dash.exceptions import PreventUpdate
-from webviz_config.webviz_assets import WEBVIZ_ASSETS
 from webviz_config.common_cache import CACHE
 from webviz_config.webviz_store import webvizstore
 from webviz_config import WebvizPluginABC
 from webviz_config import WebvizConfigTheme
 from webviz_config import WebvizSettings
 
-import webviz_subsurface
 from webviz_subsurface._models import EnsembleSetModel
 from webviz_subsurface._models import caching_ensemble_set_model_factory
 from .._abbreviations.reservoir_simulation import (
@@ -133,13 +131,6 @@ folder, to avoid risk of not extracting the right data.
 
         super().__init__()
 
-        WEBVIZ_ASSETS.add(
-            Path(webviz_subsurface.__file__).parent
-            / "_assets"
-            / "css"
-            / "block_options.css"
-        )
-
         self.column_keys = column_keys
         self.time_index = sampling
         if self.time_index not in ("daily", "monthly", "yearly"):
@@ -380,15 +371,14 @@ folder, to avoid risk of not extracting the right data.
         return wcc.FlexBox(
             id=self.uuid("layout"),
             children=[
-                html.Div(
-                    style={"flex": 1},
+                wcc.Frame(
+                    style={"flex": 1, "height": "90vh"},
                     children=[
-                        html.Label(
-                            style={"paddingBottom": "15px"},
-                            id=self.uuid("fip_array"),
+                        wcc.Selectors(
+                            label="Selectors",
                             children=[
-                                html.Div("FIP array:", style={"font-weight": "bold"}),
-                                dcc.Dropdown(
+                                wcc.Dropdown(
+                                    label="FIP array",
                                     id=self.uuid("fip"),
                                     options=[
                                         {"label": i, "value": i}
@@ -400,30 +390,14 @@ folder, to avoid risk of not extracting the right data.
                                         else self.fip_arrays[0]
                                     ),
                                     clearable=False,
-                                    persistence=True,
-                                    persistence_type="session",
                                 ),
-                            ],
-                        ),
-                        html.Label(
-                            style={"paddingBottom": "15px"},
-                            id=self.uuid("groupby"),
-                            children=[
-                                html.Div("Group by:", style={"font-weight": "bold"}),
-                                dcc.Dropdown(
+                                wcc.Dropdown(
+                                    label="Group by",
                                     id=self.selectors_id("groupby"),
                                     clearable=False,
-                                    persistence=True,
-                                    persistence_type="session",
                                 ),
-                            ],
-                        ),
-                        html.Label(
-                            style={"paddingBottom": "15px"},
-                            id=self.uuid("ensemble"),
-                            children=[
-                                html.Div("Ensembles:", style={"font-weight": "bold"}),
-                                dcc.Dropdown(
+                                wcc.Dropdown(
+                                    label="Ensembles",
                                     id=self.selectors_id("ensemble"),
                                     options=[
                                         {"label": i, "value": i} for i in self.ensembles
@@ -431,36 +405,21 @@ folder, to avoid risk of not extracting the right data.
                                     value=self.ensembles,
                                     multi=True,
                                     clearable=False,
-                                    persistence=True,
-                                    persistence_type="session",
                                 ),
-                            ],
-                        ),
-                        html.Label(
-                            style={"paddingBottom": "15px"},
-                            id=self.uuid("vector"),
-                            children=[
-                                html.Div("Time series:", style={"font-weight": "bold"}),
-                                dcc.Dropdown(
+                                wcc.Dropdown(
+                                    label="Time series",
                                     id=self.selectors_id("vector"),
                                     clearable=False,
                                     optionHeight=80,
-                                    persistence=True,
-                                    persistence_type="session",
                                 ),
                             ],
                         ),
-                        html.Label(
-                            style={"paddingBottom": "15px"},
-                            id=self.uuid("timeseries_visualization"),
+                        wcc.Selectors(
+                            label="Visualization",
                             children=[
-                                html.Div(
-                                    "Time series visualization:",
-                                    style={"font-weight": "bold"},
-                                ),
-                                dcc.RadioItems(
+                                wcc.RadioItems(
+                                    label="Time series",
                                     id=self.selectors_id("timeseries_visualization"),
-                                    className="block-options",
                                     options=[
                                         {
                                             "label": "Individual realizations",
@@ -472,20 +431,9 @@ folder, to avoid risk of not extracting the right data.
                                         },
                                     ],
                                     value="statistics",
-                                    persistence=True,
-                                    persistence_type="session",
                                 ),
-                            ],
-                        ),
-                        html.Label(
-                            style={"paddingBottom": "15px"},
-                            id=self.uuid("date_visualization"),
-                            children=[
-                                html.Div(
-                                    "Single date statistics as:",
-                                    style={"font-weight": "bold"},
-                                ),
-                                dcc.Dropdown(
+                                wcc.Dropdown(
+                                    label="Single date statistics as",
                                     id=self.selectors_id("date_view"),
                                     options=[
                                         {"label": i.lower().capitalize(), "value": i}
@@ -498,34 +446,45 @@ folder, to avoid risk of not extracting the right data.
                                     ],
                                     value="table",
                                     clearable=False,
-                                    persistence=True,
-                                    persistence_type="session",
                                 ),
                             ],
                         ),
-                        html.Div(
-                            children="Filters:",
-                            style={"font-weight": "bold"},
+                        wcc.Selectors(
+                            label="Filters:",
+                            children=html.Div(id=self.uuid("filters"), children=[]),
                         ),
-                        html.Div(id=self.uuid("filters"), children=[]),
                     ],
                 ),
-                html.Div(
-                    style={"flex": 6, "paddingLeft": "5px"},
+                wcc.FlexColumn(
+                    flex=6,
+                    style={"height": "90vh"},
                     children=[
-                        wcc.Graph(
-                            id=self.uuid("graph"),
-                            clickData={"points": [{"x": str(self.smry["DATE"].min())}]},
-                            style={"height": "450px"},
+                        wcc.Frame(
+                            color="white",
+                            highlight=False,
+                            children=wcc.Graph(
+                                id=self.uuid("graph"),
+                                clickData={
+                                    "points": [{"x": str(self.smry["DATE"].min())}]
+                                },
+                                style={"height": "40vh"},
+                            ),
                         ),
-                        html.Div(
-                            id=self.uuid("stats_title"),
-                            style={
-                                "textAlign": "center",
-                            },
-                            children="",
+                        wcc.Frame(
+                            style={"height": "45vh"},
+                            color="white",
+                            highlight=False,
+                            children=[
+                                html.Div(
+                                    id=self.uuid("stats_title"),
+                                    style={
+                                        "textAlign": "center",
+                                    },
+                                    children="",
+                                ),
+                                html.Div(id=self.uuid("date_view_wrapper")),
+                            ],
                         ),
-                        html.Div(id=self.uuid("date_view_wrapper")),
                     ],
                 ),
                 dcc.Store(
@@ -576,39 +535,26 @@ folder, to avoid risk of not extracting the right data.
             if fipdesc is None:
                 nodes = get_fip_array_nodes(fip, self.smry_cols)
                 filters = [
-                    html.Details(
-                        open=True,
-                        children=[
-                            html.Summary("Regions:"),
-                            wcc.Select(
-                                id=self.selectors_id(fip + self.uuid("regions")),
-                                options=[{"label": i, "value": i} for i in nodes],
-                                size=min([len(nodes), 10]),
-                                value=nodes,
-                                persistence=True,
-                                persistence_type="session",
-                            ),
-                        ],
-                    )
+                    wcc.SelectWithLabel(
+                        label="Regions",
+                        id=self.selectors_id(fip + self.uuid("regions")),
+                        options=[{"label": i, "value": i} for i in nodes],
+                        size=min([len(nodes), 10]),
+                        value=nodes,
+                    ),
                 ]
+
             else:
                 filters = [
-                    html.Details(
-                        open=True,
-                        children=[
-                            html.Summary(group.lower().capitalize()),
-                            wcc.Select(
-                                id=self.selectors_id(fip + self.uuid(group)),
-                                options=[
-                                    {"label": i, "value": i}
-                                    for i in group_df["SUBGROUP"].unique()
-                                ],
-                                size=min([len(group_df["SUBGROUP"].unique()), 5]),
-                                value=group_df["SUBGROUP"].unique(),
-                                persistence=True,
-                                persistence_type="session",
-                            ),
+                    wcc.SelectWithLabel(
+                        label=group.lower().capitalize(),
+                        id=self.selectors_id(fip + self.uuid(group)),
+                        options=[
+                            {"label": i, "value": i}
+                            for i in group_df["SUBGROUP"].unique()
                         ],
+                        size=min([len(group_df["SUBGROUP"].unique()), 5]),
+                        value=group_df["SUBGROUP"].unique(),
                     )
                     for group, group_df in fipdesc.groupby("GROUP")
                 ]
@@ -968,7 +914,13 @@ def render_single_date_graph(
             )
             if trace is not None:
                 traces.append(trace)
-    layout = {"height": 600, "margin": {"t": 10, "b": 230}, "showlegend": True}
+    layout = {
+        "height": 500,
+        "margin": {
+            "t": 10,
+        },
+        "showlegend": True,
+    }
 
     if date_viz == "histogram":
         layout.update(
