@@ -2,6 +2,7 @@ from typing import Callable, List, Tuple
 import json
 from uuid import uuid4
 from pathlib import Path
+import warnings
 
 import pandas as pd
 import dash_html_components as html
@@ -187,7 +188,10 @@ def get_uncompressed_data(
     if "PERMX" not in properties:
         properties.append("PERMX")
 
-    grid = ens.get_eclgrid(properties, report=time_step)
+    with warnings.catch_warnings():
+        # Grid support outside initial scope of fmu-ensemble v2. Need to consider options
+        warnings.filterwarnings("ignore", category=FutureWarning, module="fmu.ensemble")
+        grid = ens.get_eclgrid(properties, report=time_step)
 
     grid = grid[grid["PERMX"] > 0]  # Remove inactive grid cells
 
