@@ -10,18 +10,25 @@ import dash_html_components as html
 import dash_table
 import plotly.express as px
 import plotly.graph_objects as go
-
+import webviz_core_components as wcc
+from webviz_config import WebvizConfigTheme
+from webviz_subsurface._components.tornado._tornado_data import TornadoData
+from webviz_subsurface._components.tornado._tornado_bar_chart import TornadoBarChart
+from webviz_subsurface._components.tornado._tornado_table import TornadoTable
 from webviz_subsurface._models import InplaceVolumesModel
 from webviz_subsurface._abbreviations.volume_terminology import (
     volume_description,
     volume_unit,
 )
-
+from ..utils.utils import update_relevant_components
 from ..figures import create_figure
 
 # pylint: disable=too-many-statements, too-many-locals, too-many-branches
 def distribution_controllers(
-    app: dash.Dash, get_uuid: Callable, volumemodel: InplaceVolumesModel
+    app: dash.Dash,
+    get_uuid: Callable,
+    volumemodel: InplaceVolumesModel,
+    theme: WebvizConfigTheme,
 ) -> None:
     @app.callback(
         Output(
@@ -31,28 +38,25 @@ def distribution_controllers(
             {"id": get_uuid("main-voldist"), "wrapper": "table", "page": ALL},
             "children",
         ),
-        Input(get_uuid("selections-voldist"), "data"),
+        Input(get_uuid("selections"), "data"),
         Input(
             {"id": get_uuid("main-voldist"), "element": "plot-table-select"}, "value"
         ),
-        State(get_uuid("page-selected-voldist"), "data"),
+        State(get_uuid("page-selected"), "data"),
         State({"id": get_uuid("main-voldist"), "element": "graph", "page": ALL}, "id"),
-        State(
-            {"id": get_uuid("main-voldist"), "wrapper": "table", "page": ALL},
-            "id",
-        ),
+        State({"id": get_uuid("main-voldist"), "wrapper": "table", "page": ALL}, "id"),
         State(
             {"id": get_uuid("main-voldist"), "element": "graph", "page": ALL}, "figure"
         ),
     )
-    def _update_plots(
+    def _update_page_1p1t_and_custom(
         selections: dict,
         plot_table_select: str,
         page_selected: str,
         figure_ids: list,
         table_wrapper_ids: list,
         figures: list,
-    ) -> Tuple[list, list]:
+    ) -> tuple:
         ctx = dash.callback_context.triggered[0]
         if page_selected not in ["1p1t", "custom"]:
             raise PreventUpdate
@@ -67,7 +71,7 @@ def distribution_controllers(
             if not selections["update"]:
                 raise PreventUpdate
 
-        groups = ["ENSEMBLE", "REAL"]
+        groups = ["REAL"]
         parameters = []
         responses = []
         for item in ["Subplots", "Color by", "X Response", "Y Response"]:
@@ -88,23 +92,30 @@ def distribution_controllers(
                 ):
                     responses.append(selections[item])
 
-        dframe = volumemodel.dataframe.copy()
+        dframe = volumemodel.get_df(
+            filters=selections["filters"], groups=groups, parameters=parameters
+        )
 
-        if parameters:
-            columns = parameters + ["REAL", "ENSEMBLE"]
-            dframe = pd.merge(
-                dframe, volumemodel.parameter_df[columns], on=["REAL", "ENSEMBLE"]
+        prevent_fig_update = (
+            (page_selected == "custom" and plot_table_select == "table")
+            or "Table type" in selections["ctx_clicked"]
+            or (
+                not selections["sync_table"]
+                and any(
+                    x in selections["ctx_clicked"]
+                    for x in ["Group by", "table_responses"]
+                )
             )
-        dframe = filter_df(dframe, selections["filters"])
+        )
 
-        # Need to sum volume columns and take the average of property columns
-        aggregations = {x: "sum" for x in volumemodel.volume_columns}
-        aggregations.update({x: "mean" for x in parameters})
-
-        df_for_figure = dframe.groupby(groups).agg(aggregations).reset_index()
-        df_for_figure = volumemodel.compute_property_columns(df_for_figure)
-
-        if not (plot_table_select == "table" and page_selected == "custom"):
+        if not prevent_fig_update:
+            df_for_figure = (
+                dframe
+                if not (selections["Plot type"] == "bar" and groups != ["REAL"])
+                else dframe.groupby([x for x in groups if x != "REAL"])
+                .mean()
+                .reset_index()
+            )
             figure = create_figure(
                 plot_type=selections["Plot type"],
                 data_frame=df_for_figure,
@@ -134,6 +145,11 @@ def distribution_controllers(
                 yaxis=dict(showticklabels=True),
             ).add_annotation(fluid_annotation(selections))
 
+            if selections["X Response"] in volumemodel.selectors:
+                figure.update_xaxes(
+                    dict(type="category", tickangle=45, tickfont_size=12)
+                )
+
             if selections["Subplots"] is not None:
                 if not selections["X axis matches"]:
                     figure.update_xaxes({"matches": None})
@@ -150,16 +166,17 @@ def distribution_controllers(
                     table_groups.extend(
                         [x for x in selections["Group by"] if x not in table_groups]
                     )
-                df_for_table = (
-                    dframe.groupby(table_groups).agg(aggregations).reset_index()
+                df_for_table = volumemodel.get_df(
+                    filters=selections["filters"],
+                    groups=table_groups,
+                    parameters=parameters,
                 )
-                df_for_table = volumemodel.compute_property_columns(df_for_table)
 
                 responses = selections["table_responses"]
                 groups = selections["Group by"]
 
             table_wrapper_children = make_table_wrapper_children(
-                dframe=df_for_figure if selections["sync_table"] else df_for_table,
+                dframe=dframe if selections["sync_table"] else df_for_table,
                 responses=responses,
                 groups=groups,
                 volumemodel=volumemodel,
@@ -169,21 +186,20 @@ def distribution_controllers(
         else:
             table_wrapper_children = dash.no_update
 
-        figures = []
-        for fig_id in figure_ids:
-            if fig_id["page"] == page_selected:
-                figures.append(figure)
-            else:
-                figures.append(dash.no_update)
-
-        table_wrappers = []
-        for wrap_id in table_wrapper_ids:
-            if wrap_id["page"] == page_selected:
-                table_wrappers.append(table_wrapper_children)
-            else:
-                table_wrappers.append(dash.no_update)
-
-        return (figures, table_wrappers)
+        return tuple(
+            update_relevant_components(
+                id_list=id_list,
+                update_info=[
+                    {
+                        "new_value": val,
+                        "conditions": {"page": page_selected},
+                    }
+                ],
+            )
+            for val, id_list in zip(
+                [figure, table_wrapper_children], [figure_ids, table_wrapper_ids]
+            )
+        )
 
     @app.callback(
         Output(
@@ -195,8 +211,8 @@ def distribution_controllers(
             },
             "figure",
         ),
-        Input(get_uuid("selections-voldist"), "data"),
-        State(get_uuid("page-selected-voldist"), "data"),
+        Input(get_uuid("selections"), "data"),
+        State(get_uuid("page-selected"), "data"),
         State(
             {
                 "id": get_uuid("main-voldist"),
@@ -216,7 +232,7 @@ def distribution_controllers(
             "figure",
         ),
     )
-    def _update_plots_per_region_zone(
+    def _update_page_per_zr(
         selections: dict,
         page_selected: str,
         figure_ids: List[dict],
@@ -234,24 +250,10 @@ def distribution_controllers(
             if not selections["update"]:
                 raise PreventUpdate
 
-        dframe = volumemodel.dataframe.copy()
-        dframe = filter_df(dframe, selections["filters"])
-
         figs = {}
         for selector in [x["selector"] for x in figure_ids]:
-            groups = ["ENSEMBLE", "REAL"]
-
-            groups.append(selector)
-
-            aggregations = {x: "sum" for x in volumemodel.volume_columns}
-            df_group = dframe.groupby(groups).agg(aggregations).reset_index()
-            df_group = volumemodel.compute_property_columns(df_group)
-
-            # find mean over realizations
-            df_merged = (
-                df_group.groupby([x for x in groups if x != "REAL"])
-                .mean()
-                .reset_index()
+            dframe = volumemodel.get_df(
+                filters=selections["filters"], groups=[selector]
             )
             texttemplate = (
                 "%{text:.3s}"
@@ -262,7 +264,7 @@ def distribution_controllers(
             figs[selector] = {
                 "pie": create_figure(
                     plot_type="pie",
-                    data_frame=df_merged,
+                    data_frame=dframe,
                     values=selections["X Response"],
                     names=selector,
                     title=f"{selections['X Response']} per {selector}",
@@ -273,7 +275,7 @@ def distribution_controllers(
                 .update_layout(margin=dict(l=10, b=10)),
                 "bar": create_figure(
                     plot_type="bar",
-                    data_frame=df_merged,
+                    data_frame=dframe,
                     x=selector,
                     y=selections["X Response"],
                     color_discrete_sequence=px.colors.diverging.BrBG_r,
@@ -297,14 +299,14 @@ def distribution_controllers(
             {"id": get_uuid("main-voldist"), "element": "plot", "page": "conv"},
             "figure",
         ),
-        Input(get_uuid("selections-voldist"), "data"),
-        State(get_uuid("page-selected-voldist"), "data"),
+        Input(get_uuid("selections"), "data"),
+        State(get_uuid("page-selected"), "data"),
         State(
             {"id": get_uuid("main-voldist"), "element": "plot", "page": "conv"},
             "figure",
         ),
     )
-    def _update_convergence_plot(
+    def _update_page_conv(
         selections: dict, page_selected: str, figure: go.Figure
     ) -> go.Figure:
         if page_selected != "conv":
@@ -317,18 +319,13 @@ def distribution_controllers(
             if not selections["update"]:
                 raise PreventUpdate
 
-        dframe = volumemodel.dataframe.copy()
-        dframe = filter_df(dframe, selections["filters"])
-
         subplots = selections["Subplots"] if selections["Subplots"] is not None else []
-        groups = ["ENSEMBLE", "REAL"]
+        groups = ["REAL"]
         if subplots and subplots not in groups:
             groups.append(subplots)
 
-        aggregations = {x: "sum" for x in volumemodel.volume_columns}
-        dframe = dframe.groupby(groups).agg(aggregations).reset_index()
-        dframe = volumemodel.compute_property_columns(dframe)
-        dframe = dframe.sort_values(by=["ENSEMBLE", "REAL"])
+        dframe = volumemodel.get_df(filters=selections["filters"], groups=groups)
+        dframe = dframe.sort_values(by=["REAL"])
 
         dfs = []
         df_groups = dframe.groupby(subplots) if subplots else [(None, dframe)]
@@ -377,6 +374,150 @@ def distribution_controllers(
                 figure.update_yaxes(dict(matches=None))
         return figure
 
+    @app.callback(
+        Output(
+            {
+                "id": get_uuid("main-tornado"),
+                "element": "bulktornado",
+                "page": "tornado",
+            },
+            "figure",
+        ),
+        Output(
+            {
+                "id": get_uuid("main-tornado"),
+                "element": "inplacetornado",
+                "page": "tornado",
+            },
+            "figure",
+        ),
+        Output(
+            {
+                "id": get_uuid("main-tornado"),
+                "wrapper": "table",
+                "page": "tornado",
+            },
+            "children",
+        ),
+        Input(get_uuid("selections"), "data"),
+        State(get_uuid("page-selected"), "data"),
+        State(
+            {
+                "id": get_uuid("main-tornado"),
+                "element": "bulktornado",
+                "page": "tornado",
+            },
+            "figure",
+        ),
+    )
+    def _update_page_tornado(
+        selections: dict, page_selected: str, figure: go.Figure
+    ) -> go.Figure:
+
+        if page_selected != "tornado":
+            raise PreventUpdate
+
+        selections = selections[page_selected]
+        initial_callback = figure is None
+        if not initial_callback:
+            if not selections["update"]:
+                raise PreventUpdate
+
+        filters = selections["filters"].copy()
+
+        figures = []
+        tables = []
+        for x in ["BULK", selections["Volume response"]]:
+
+            sensfilter = (
+                selections["Bulk sensitivities"]
+                if x == "BULK"
+                else selections["Volume sensitivities"]
+            )
+            if selections["Reference"] not in sensfilter:
+                sensfilter.append(selections["Reference"])
+
+            # filter on correct fluid zone depending on chosen volume response
+            fluid_filter = [
+                "oil" if selections["Volume response"] == "STOIIP" else "gas"
+            ]
+            filters.update(
+                SENSNAME=sensfilter,
+                FLUID_ZONE=fluid_filter,
+            )
+
+            groups = ["REAL", "ENSEMBLE", "SENSNAME", "SENSCASE", "SENSTYPE"]
+            df_for_tornado = volumemodel.get_df(filters=filters, groups=groups)
+            df_for_tornado.rename(columns={x: "VALUE"}, inplace=True)
+
+            tornado_data = TornadoData(
+                dframe=df_for_tornado,
+                reference=selections["Reference"],
+                response_name=x,
+                scale=selections["Scale"],
+                cutbyref=bool(selections["Remove no impact"]),
+            )
+            figure = TornadoBarChart(
+                tornado_data=tornado_data,
+                plotly_theme=theme.plotly_theme,
+                label_options=selections["labeloptions"],
+                number_format="#.3g",
+                use_true_base=selections["Scale"] == "True",
+                show_realization_points=bool(selections["real_scatter"]),
+            ).figure
+
+            figure.update_xaxes(
+                gridwidth=1,
+                gridcolor="whitesmoke",
+                showgrid=True,
+                side="bottom",
+                title=None,
+            ).update_layout(
+                title=dict(
+                    text=f"Tornadoplot for {x} "
+                    + (f"({fluid_filter[0]})" if x == "BULK" else ""),
+                    font=dict(size=18),
+                ),
+                margin={"t": 70},
+                hovermode="closest",
+            ).update_traces(
+                hovertemplate="REAL: %{text}<extra></extra>",
+                selector={"type": "scatter"},
+            )
+
+            figures.append(figure)
+
+            tornado_table = TornadoTable(tornado_data=tornado_data)
+            table_data = tornado_table.as_plotly_table
+            for data in table_data:
+                data["Reference"] = tornado_data.reference_average
+            tables.append(table_data)
+
+        return (
+            figures[0],
+            figures[1],
+            html.Div(
+                children=[
+                    html.Div(
+                        style={"margin-top": "20px"},
+                        children=create_data_table(
+                            volumemodel=volumemodel,
+                            columns=tornado_table.columns
+                            + create_table_columns(
+                                columns=["Reference"],
+                                format_columns=["Reference"],
+                                use_si_format=True,
+                            ),
+                            data=table,
+                            height="20vh",
+                            table_id={"table_id": f"{page_selected}-table{idx}"},
+                        ),
+                    )
+                    for idx, table in enumerate(tables)
+                ]
+            ),
+        )
+
 
 # pylint: disable=too-many-locals
 def make_table_wrapper_children(
@@ -389,19 +530,10 @@ def make_table_wrapper_children(
 ) -> Tuple[list, list]:
 
     groups = groups if groups is not None else []
-    groupby_real = (
-        selections["Group by"] is not None and "REAL" in selections["Group by"]
-    )
-    groups = (
-        groups
-        if groupby_real and selections["Table type"] != "Statistics table"
-        else [x for x in groups if x != "REAL"]
-    )
-    vol_responses = [x for x in responses if x in volumemodel.volume_columns]
 
     if selections["Table type"] == "Statistics table":
         statcols = ["Mean", "Stddev", "P90", "P10", "Minimum", "Maximum"]
-
+        groups = [x for x in groups if x != "REAL"]
         df_groups = dframe.groupby(groups) if groups else [(None, dframe)]
 
         data_properties = []
@@ -412,7 +544,9 @@ def make_table_wrapper_children(
             for name, df in df_groups:
                 values = df[response]
                 data = {
-                    "Response" if response in vol_responses else "Property": response,
+                    "Response"
+                    if response in volumemodel.volume_columns
+                    else "Property": response,
                     "Mean": values.mean(),
                     "Stddev": values.std(),
                     "P10": np.nanpercentile(values, 90),
@@ -420,8 +554,10 @@ def make_table_wrapper_children(
                     "Minimum": values.min(),
                     "Maximum": values.max(),
                 }
-                if "FLUID" not in groups:
-                    data.update(FLUID=(" + ").join(selections["filters"]["FLUID"]))
+                if "FLUID_ZONE" not in groups:
+                    data.update(
+                        FLUID_ZONE=(" + ").join(selections["filters"]["FLUID_ZONE"])
+                    )
 
                 for idx, group in enumerate(groups):
                     data[group] = (
@@ -440,42 +576,35 @@ def make_table_wrapper_children(
         return html.Div(
             children=[
                 html.Div(
-                    style={"margin-bottom": "30px"}
-                    if all([data_volcols, data_properties])
-                    else None,
+                    style={"margin-top": "20px"},
                     children=create_data_table(
                         volumemodel=volumemodel,
                         columns=create_table_columns(
-                            columns=["Response"]
-                            + [x for x in groups if x != "FLUID"]
+                            columns=[col]
+                            + [x for x in groups if x != "FLUID_ZONE"]
                             + statcols
-                            + ["FLUID"],
+                            + ["FLUID_ZONE"],
                             format_columns=statcols,
-                            volumemodel=volumemodel,
-                            use_si_format=True,
+                            use_si_format=col == "Response",
                         ),
-                        data=data_volcols,
+                        data=data,
                         height=height,
+                        table_id={"table_id": f"{page_selected}-{col}"},
                     ),
-                ),
-                create_data_table(
-                    volumemodel=volumemodel,
-                    columns=create_table_columns(
-                        columns=["Property"]
-                        + [x for x in groups if x != "FLUID"]
-                        + statcols
-                        + ["FLUID"],
-                        format_columns=statcols,
-                        volumemodel=volumemodel,
-                        use_si_format=False,
-                    ),
-                    data=data_properties,
-                    height=height,
-                ),
+                )
+                for col, data in zip(
+                    ["Response", "Property"], [data_volcols, data_properties]
+                )
             ]
         )
 
     # if table type Mean table
+    groupby_real = (
+        selections["Group by"] is not None and "REAL" in selections["Group by"]
+    )
+    if "REAL" in groups and not groupby_real:
+        groups.remove("REAL")
+
     columns = responses + [x for x in groups if x not in responses]
     dframe = (
         dframe[columns].groupby(groups).mean().reset_index()
@@ -483,10 +612,10 @@ def make_table_wrapper_children(
         else dframe[responses].mean().to_frame().T
     )
 
-    if "FLUID" not in dframe:
-        dframe["FLUID"] = (" + ").join(selections["filters"]["FLUID"])
+    if "FLUID_ZONE" not in dframe:
+        dframe["FLUID_ZONE"] = (" + ").join(selections["filters"]["FLUID_ZONE"])
 
-    dframe = dframe[[x for x in dframe.columns if x != "FLUID"] + ["FLUID"]]
+    dframe = dframe[[x for x in dframe.columns if x != "FLUID_ZONE"] + ["FLUID_ZONE"]]
     return html.Div(
         children=[
             create_data_table(
@@ -498,24 +627,21 @@ def make_table_wrapper_children(
                 ),
                 data=dframe.iloc[::-1].to_dict("records"),
                 height="88vh" if page_selected == "custom" else "44vh",
+                table_id={"table_id": f"{page_selected}-meantable"},
             )
         ]
     )
 
 
-def filter_df(dframe: pd.DataFrame, filters: dict) -> pd.DataFrame:
-    for filt, values in filters.items():
-        dframe = dframe.loc[dframe[filt].isin(values)]
-    return dframe
-
-
 def create_table_columns(
     columns: list,
-    format_columns: list,
-    volumemodel: InplaceVolumesModel,
-    use_si_format: bool = None,
+    volumemodel: Optional[InplaceVolumesModel] = None,
+    format_columns: Optional[list] = None,
+    use_si_format: Optional[bool] = None,
 ) -> List[dict]:
 
+    format_columns = format_columns if format_columns is not None else []
+
     table_columns = []
     for col in columns:
         data = {"id": col, "name": col}
@@ -524,7 +650,9 @@ def create_table_columns(
                 {
                     "type": "numeric",
                     "format": {"locale": {"symbol": ["", ""]}, "specifier": "$.4s"}
-                    if col in volumemodel.volume_columns or use_si_format
+                    if use_si_format
+                    or volumemodel is not None
+                    and col in volumemodel.volume_columns
                     else Format(precision=3),
                 }
             )
@@ -537,7 +665,8 @@ def create_data_table(
     volumemodel: InplaceVolumesModel,
     columns: list,
     height: str,
-    data: Optional[list],
+    data: List[dict],
+    table_id: dict,
 ) -> dash_table.DataTable:
 
     if not data:
@@ -545,47 +674,62 @@ def create_data_table(
 
     style_cell_conditional = [
         {"if": {"column_id": c}, "textAlign": "left"}
-        for c in [x for x in volumemodel.selectors if x != "FLUID"]
-        + ["Response", "Property"]
+        for c in [x for x in volumemodel.selectors if x != "FLUID_ZONE"]
+        + ["Response", "Property", "Sensitivity"]
     ]
     style_cell_conditional.extend(
         [
-            {"if": {"column_id": c}, "width": "15%"}
-            for c in volumemodel.selectors + ["Response", "Property"]
+            {"if": {"column_id": c}, "width": "10%"}
+            for c in volumemodel.selectors + ["Response", "Property", "Sensitivity"]
         ]
     )
-    style_data_conditional = [
-        {
-            "if": {"filter_query": "{FLUID} = " + f"'{fluid}'", "column_id": "FLUID"},
-            "backgroundColor": color,
-        }
-        for fluid, color in fluid_colors().items()
-    ]
+    style_data_conditional = fluid_table_style()
 
-    return dash_table.DataTable(
-        sort_action="native",
-        sort_mode="multi",
-        filter_action="native",
-        columns=columns,
-        data=data,
-        style_cell_conditional=style_cell_conditional,
-        style_data_conditional=style_data_conditional,
-        style_table={
-            "height": height,
-            "overflowY": "auto",
-        },
+    return wcc.WebvizPluginPlaceholder(
+        id={"request": "table_data", "table_id": table_id["table_id"]},
+        buttons=["expand", "download"],
+        children=dash_table.DataTable(
+            id=table_id,
+            sort_action="native",
+            sort_mode="multi",
+            filter_action="native",
+            columns=columns,
+            data=data,
+            style_as_list_view=True,
+            style_cell_conditional=style_cell_conditional,
+            style_data_conditional=style_data_conditional,
+            style_table={
+                "height": height,
+                "overflowY": "auto",
+            },
+        ),
     )
 
 
-def fluid_colors() -> dict:
-    return {"oil": "#c6ebd9", "gas": "#ffcccc", "oil + gas": "#E8E8E8"}
+def fluid_table_style() -> list:
+    fluid_colors = {
+        "oil": "#007079",
+        "gas": "#FF1243",
+        "water": "#ADD8E6",
+    }
+    return [
+        {
+            "if": {
+                "filter_query": "{FLUID_ZONE} = " + f"'{fluid}'",
+                "column_id": "FLUID_ZONE",
+            },
+            "color": color,
+            "fontWeight": "bold",
+        }
+        for fluid, color in fluid_colors.items()
+    ]
 
 
 def fluid_annotation(selections: dict) -> dict:
-    fluid_text = (" + ").join(selections["filters"]["FLUID"])
+    fluid_text = (" + ").join(selections["filters"]["FLUID_ZONE"])
     return dict(
         visible=bool(selections["Fluid annotation"])
-        and selections["Subplots"] != "FLUID",
+        and selections["Subplots"] != "FLUID_ZONE",
         x=1,
         y=1,
         xref="paper",
@@ -593,5 +737,5 @@ def fluid_annotation(selections: dict) -> dict:
         showarrow=False,
         text="Fluid zone<br>" + fluid_text,
         font=dict(size=15, color="black"),
-        bgcolor=fluid_colors()[fluid_text],
+        bgcolor="#E8E8E8",
     )
